@@ -1,7 +1,7 @@
 package App::dateseq;
 
-our $DATE = '2015-09-26'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-09-28'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,7 +14,7 @@ $SPEC{dateseq} = {
     summary => 'Generate a sequence of dates',
     description => <<'_',
 
-This utility is similar to Unix `seq` command, except that it generates a
+This utility is similar to Unix <prog:seq> command, except that it generates a
 sequence of dates.
 
 _
@@ -26,20 +26,25 @@ _
     args => {
         from => {
             summary => 'Starting date',
-            schema => 'date*',
-            'x.perl.coerce_to' => 'DateTime',
+            schema => ['date*', {
+                'x.perl.coerce_to' => 'DateTime',
+                'x.perl.coerce_rules' => ['str_alami_en'],
+            }],
             req => 1,
             pos => 0,
         },
         to => {
             summary => 'End date, if not specified will generate an infinite* stream of dates',
-            schema => 'date*',
-            'x.perl.coerce_to' => 'DateTime',
+            schema => ['date*', {
+                'x.perl.coerce_to' => 'DateTime',
+                'x.perl.coerce_rules' => ['str_alami_en'],
+            }],
             pos => 1,
         },
         increment => {
-            schema => 'duration*',
-            'x.perl.coerce_to' => 'DateTime::Duration',
+            schema => ['duration*', {
+                'x.perl.coerce_to' => 'DateTime::Duration',
+            }],
             cmdline_aliases => {i=>{}},
             pos => 2,
         },
@@ -77,36 +82,49 @@ _
             summary => 'Generate dates from 2015-01-01 to 2015-01-31',
             src => '[[prog]] 2015-01-01 2015-01-31',
             src_plang => 'bash',
+            'x.doc.max_result_lines' => 5,
+        },
+        {
+            summary => 'Generate dates from 2015-01-01 to today',
+            src => '[[prog]] 2015-01-01 today',
+            src_plang => 'bash',
+            'x.doc.max_result_lines' => 5,
         },
         {
             summary => 'Generate dates with increment of 3 days',
             src => '[[prog]] 2015-01-01 2015-01-31 -i P3D',
             src_plang => 'bash',
+            'x.doc.max_result_lines' => 5,
         },
         {
             summary => 'Generate a CSV data',
             src => '[[prog]] 2010-01-01 2015-01-31 -f "%Y,%m,%d" --header "year,month,day"',
             src_plang => 'bash',
+            'x.doc.max_result_lines' => 5,
         },
         {
             summary => 'Generate periods (YYYY-MM)',
             src => '[[prog]] 2010-01-01 2015-12-31 -i P1M -f "%Y-%m"',
             src_plang => 'bash',
+            'x.doc.max_result_lines' => 5,
         },
         {
             summary => 'List non-holidays in 2015 (using Indonesian holidays)',
             src => 'setop --diff <([[prog]] 2015-01-01 2015-12-31) <(list-id-holidays --year 2015)',
             src_plang => 'bash',
+            'x.doc.max_result_lines' => 10,
         },
         {
             summary => 'List non-holidays business days in 2015 (using Indonesian holidays)',
             src => 'setop --diff <([[prog]] 2015-01-01 2015-12-31 --business) <(list-id-holidays --year 2015)',
             src_plang => 'bash',
+            'x.doc.max_result_lines' => 10,
         },
         {
             summary => 'Use with fsql',
             src => q{[[prog]] 2010-01-01 2015-12-01 -f "%Y,%m" -i P1M --header "year,month" | fsql --add-csv - --add-csv data.csv -F YEAR -F MONTH 'SELECT year, month, data1 FROM stdin WHERE YEAR(data.date)=year AND MONTH(data.date)=month'},
             src_plang => 'bash',
+            'x.doc.show_result' => 0,
         },
     ],
 };
@@ -202,7 +220,7 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.06 of App::dateseq (from Perl distribution App-dateseq), released on 2015-09-26.
+This document describes version 0.07 of App::dateseq (from Perl distribution App-dateseq), released on 2016-09-28.
 
 =head1 FUNCTIONS
 
@@ -211,9 +229,11 @@ This document describes version 0.06 of App::dateseq (from Perl distribution App
 
 Generate a sequence of dates.
 
-This utility is similar to Unix C<seq> command, except that it generates a
+This utility is similar to Unix L<seq> command, except that it generates a
 sequence of dates.
 
+This function is not exported.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -286,7 +306,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
